declare enum LogType {
    T101 = "101",
    T102 = "102",
    T103 = "103",
    T104 = "104",
    T105 = "105",
    T111 = "111",
    T112 = "112",
    T113 = "113",
    T121 = "121"
}
interface IInitConfig {
    openId: string;
    unionId: string;
    userId: string;
    contentId: number;
    columnId: number;
    clientHeight: number;
    character: string;
    sessionId?: string;
    title: string;
    columnName: string;
    keyWords?: string | null;
    contentCreateTime: string | number;
    isShared?: boolean;
    sellerId?: string | number | null;
    sellerName?: string | null;
    department?: string | null;
}
interface ILogConfig {
    openId: string;
    unionId: string;
    deviceId: string;
    contentId: number;
    columnId: number;
    sessionId: string;
    character: string;
    tenantId: string;
    title: string;
    columnName: string;
    keyWords: string | null;
    isShared: boolean;
    sellerId?: string | number | null;
    sellerName?: string | null;
    department?: string | null;
}
interface IWXSystemInfo {
    SDKVersion: string;
    batteryLevel: number;
    brand: string;
    deviceOrientation: string;
    errMsg: string;
    fontSizeSetting: number;
    language: string;
    model: string;
    pixelRatio: number;
    platform: string;
    safeArea: any;
    screenHeight: number;
    screenWidth: number;
    statusBarHeight: number;
    system: string;
    version: string;
    windowHeight: number;
    windowWidth: number;
}
declare type IMPSystemInfo = Pick<IWXSystemInfo, "SDKVersion" | "batteryLevel" | "brand" | "language" | "platform" | "screenHeight" | "screenWidth" | "statusBarHeight" | "system" | "windowHeight">;

declare abstract class Base {
    protected logConfig: ILogConfig;
    protected startTime: number;
    protected postlossed: boolean;
    protected isScrollBottom: boolean;
    protected mpSystemInfo: IMPSystemInfo;
    constructor(config: IInitConfig);
    private getLogConfig;
    protected send(type: LogType, metadata?: any): void;
    abstract event_page_pv(): void;
    abstract event_page_access_time(timeout?: number): void;
    abstract event_page_hotaccess_time(scrollHeight: number, clientHeight: number, scrollTop: number): void;
    abstract event_page_loss_access(): void;
    abstract event_page_send_position(scrollHeight: number, clientHeight: number, scrollTop: number): void;
    abstract event_page_download(userInfo: {
        id: string | number;
        name: string;
        department: string;
    }): void;
    upgradeColumnId(columnId: number): void;
    private getSystemInfo;
}

declare class Log extends Base {
    private heatmap?;
    private accesstime?;
    private scrollTimestamp;
    private maxScrollPercent;
    private clientHeight;
    private contentCreateTime;
    constructor(config: IInitConfig);
    event_page_pv(): void;
    event_page_access_time(timeout?: number): void;
    event_page_hotaccess_time(scrollHeight: number, scrollTop: number): void;
    event_page_loss_access(): void;
    event_page_hide(): void;
    event_page_show(): void;
    event_page_send_position(scrollHeight: number, scrollTop: number): void;
    event_page_unload(): void;
    event_page_useful(): void;
    event_page_download(): void;
    event_page_share(): void;
}

declare const _default: {
    Log: typeof Log;
};

export default _default;
